"use client";
import { useState } from "react";
import DataTable from "@/components/tables/DataTable";
import { TableData } from "@/variables/columnsData";
import { DeleteIcon } from "@chakra-ui/icons";
import { Flex, Button, Icon, useColorModeValue } from "@chakra-ui/react";
import useShowToast from "@/app/hooks/useShowToast";
import { useRouter } from "next/navigation";
import { hasPermission } from "@/utils/navigation";
import { useGeneral } from "@/contexts/GeneralContext";
import { deleteAttempt } from "@/app/lib/attempt/action";
import { columnDataAttempts } from "../variables/columns";

export interface Attempt {
  id: number;
  name: string;
}

interface AttemptsTableProps {
  attempts: Attempt[];
}

const AttemptsTable: React.FC<AttemptsTableProps> = ({ attempts }) => {
  const { currentUser } = useGeneral();
  const brandColor = useColorModeValue("brand.500", "white");
  const router = useRouter();
  const showToast = useShowToast();
  const [loading, setLoading] = useState<number | null>(null);

  const handleDelete = async (id: number) => {
    setLoading(id);
    try {
      const response = await deleteAttempt(id);
      if (response.status === false) {
        throw new Error(response.message || "Failed to delete attempt.");
      }
      showToast("Attempt Deleted!", response.message, "success");
      router.refresh();
    } catch (error: any) {
      showToast("Failed to delete", error.message, "error");
    } finally {
      setLoading(null);
    }
  };

  const actions = (id: number) => (
    <Flex gap={2}>
      {hasPermission(currentUser.permissions, "attempt", "delete") && (
        <Button
          variant="blank"
          alignItems="center"
          justifyContent="center"
          w="24px"
          h="24px"
          lineHeight="100%"
          borderRadius="10px"
          minW={0}
          onClick={() => handleDelete(id)}
          isDisabled={loading === id || !hasPermission(currentUser.permissions, "attempt", "delete")}
        >
          <Icon as={DeleteIcon} color={brandColor} w="20px" h="20px" />
        </Button>
      )}
    </Flex>
  );

  return (
    <DataTable
      columnsData={columnDataAttempts}
      tableData={attempts as unknown as TableData[]}
      isSelectable={false}
      showPageSize={false}
      actionSlot={actions}
    />
  );
};

export default AttemptsTable;
